@@ -2223,7 +2223,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.1.2", 1);
+    setenv("SAPHIRE_VERSION", "3.1.3", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3149,6 +3149,13 @@ sBlock* sBlock_load(int fd)
         vector_add(self->mArgs, buf2);
     }
 
+    /// mCount ///
+    if(read(fd, &n, sizeof(int)) < 0) {
+        perror("read");
+        exit(1);
+    }
+    self->mCount = n;
+
     return self;
 }
 
@@ -3177,5 +3184,12 @@ void sBlock_save(sBlock* self, int fd)
             exit(1);
         }
     }
+
+    /// mCount ///
+    n = self->mCount;
+    if(write(fd, &n, sizeof(int)) < 0) {
+        perror("write");
+        exit(1);
+    }
 }
 
