@@ -1281,7 +1281,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
             }
             else {
                 char buf[128];
-                snprintf(buf, 128, "unexpected token1 --> %c", **p);
+                snprintf(buf, 128, "unexpected token -->%c\n", **p);
                 err_msg(buf, sname, *sline);
                 return FALSE;
             }
@@ -1316,7 +1316,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
             }
             else {
                 char buf[128];
-                snprintf(buf, 128, "unexpected token2 --> %c", **p);
+                snprintf(buf, 128, "unexpected token -->%c\n", **p);
                 err_msg(buf, sname, *sline);
                 return FALSE;
             }
@@ -1563,7 +1563,7 @@ BOOL parse(char* cmdline, char* sname, int* sline, sStatments* statments)
         }
         else {
             char buf[128];
-            snprintf(buf, 128, "unexpected token3 -->%c\n", *p);
+            snprintf(buf, 128, "unexpected token -->%c\n", *p);
             err_msg(buf, sname, *sline);
             return FALSE;
         }
