@@ -500,10 +500,12 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
     for(ii=0; ii<vector_size(command->mArgs); ii++) {
         sArg* arg = vector_item(command->mArgs, ii);
         switch(arg->mKind) {
+            /// string ///
             case 0:
                 vector_add(argv, STRING_NEW(string_c_str(arg->mBody)));
                 break;
 
+            /// @ のコマンド展開　///
             case 2: {
                 sStatments* statments = arg->mBody;
                 sWFd* pipeout = sWFd_new(-1);
@@ -521,6 +523,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 }
                 break;
 
+            /// @@のコマンド展開 ///
             case 4: {
                 sStatments* statments = arg->mBody;
                 sWFd* pipeout = sWFd_new(-1);
@@ -553,15 +556,17 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 }
                 break;
 
+            /// ブロック ///
             case 5: {
                 vector_add(blocks, arg->mBody);
                 }
                 break;
 
+            /// プロセス置換 ///
             case 6: {
                 sStatments* statments = arg->mBody;
                 sWFd* pipeout = sWFd_new(-1);
-                int rcode = run(statments, "quick command expansion"
+                int rcode = run(statments, "process substitution"
                     , pipeout, pipein, 2, return_, parent_blocks, FALSE);
 
                 if(rcode == -1) {
